@@ -8,6 +8,7 @@ use MP3::PodcastFetch::TagManager;
 
 use LWP::UserAgent;
 use HTTP::Status;
+use URI::Escape;
 
 use File::Spec;
 use File::Basename 'basename';
@@ -17,7 +18,7 @@ use Digest::MD5 qw(md5_hex);
 use Date::Parse;
 use Cwd;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 =head1 NAME
 
@@ -60,10 +61,11 @@ This module implements the following methods:
 =cut
 
 BEGIN {
-  my @accessors = qw(base subdir rss
+  my @accessors = qw(base subdir override_channel_dir rss
 		     max timeout mirror_mode verbose rewrite_filename upgrade_tags use_pub_date
 		     keep_old playlist_handle playlist_base force_genre force_artist
 		     force_album fetch_callback delete_callback env_proxy);
+
   for my $accessor (@accessors) {
 eval <<END;
 sub $accessor {
@@ -94,6 +96,11 @@ appropriately-named subdirectories of this location, one subdirectory
 per channel. Additional subdirectory levels can be added using the
 B<-subdirs> argument. This argument is required.
 
+=item -override_channel_dir
+
+Default is to use directory named after a channel title.  Specify
+another directory instead.
+
 =item -rss
 
 The URL of the RSS feed to subscribe to. This is usually indicated in
@@ -275,6 +282,7 @@ on every deleted file immediately after the file is deleted.
 # arguments:
 # -base             => base directory for podcasts, e.g. /var/podcasts
 # -subdir           => subdirectory for this podcast, e.g. music
+# -override_channel_dir            => directory to use instead of channel title
 # -rss              => url of the RSS feed to read
 # -max              => maximum number of episodes to keep
 # -timeout          => timeout for URL requests
@@ -299,6 +307,7 @@ sub new {
   my $self = bless {},ref $class || $class;
   $self->base($args{-base}       || '/tmp/podcasts');
   $self->subdir($args{-subdir});
+  $self->override_channel_dir($args{-override_channel_dir});
   $self->rss($args{-rss}         || croak 'please provide -rss argument');
   $self->max($args{-max}                             );
   $self->timeout($args{-timeout} || 30               );
@@ -338,6 +347,8 @@ Where $new_value is optional.
 
 =item $feed->subdir
 
+=item $feed->override_channel_dir
+
 =item $feed->rss
 
 =item $feed->timeout
@@ -481,8 +492,11 @@ sub update {
 }
 
 =item $feed->bump_fetched($value)
+
 =item $feed->bump_error($value)
+
 =item $feed->bump_deleted($value)
+
 =item $feed->bump_skipped($value)
 
 Increase the fetched, error, deleted and skipped counters by $value,
@@ -818,7 +832,7 @@ sub make_filename {
     $name   .= ".$extension" if defined $extension;
     return $name;
   } else {
-  	return basename($url);
+  	return uri_unescape( basename($url) );
   }
 }
 
@@ -849,14 +863,19 @@ sub generate_directory {
 
 =item $dirname = $feed->channel_dir($channel)
 
-Generate a directory named based on the provided channel object's title.
+Generate a directory named based on the provided channel object's title,
+unless it is overriden by B<-override_channel_dir> value.
 
 =cut
 
 sub channel_dir {
   my $self    = shift;
   my $channel = shift;
-  return $self->safestr($channel->title); # potential bug here -- what if two podcasts have same title?
+
+  my $dir = $self->override_channel_dir || $channel->title;
+
+  return
+    $self->safestr( $dir ); # potential bug here -- what if two podcasts have same title?
 }
 
 =item $safe_str = $feed->safe_str($unsafe_str)
